"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var dayjs_1 = __importDefault(require("dayjs"));
var object_omit_1 = __importDefault(require("object.omit"));
var Input_1 = __importDefault(require("../input/Input"));
var Calendar_1 = __importDefault(require("../icons/Calendar"));
var Clock_1 = __importDefault(require("../icons/Clock"));
var date_1 = __importDefault(require("./panel/date"));
var popup_1 = __importDefault(require("../_base/popup"));
var helper_1 = require("../_base/helper");
var I18n_1 = __importDefault(require("./utils/I18n"));
require("./style/index.scss");
var defaultFormat = {
    date: 'YYYY-MM-DD',
    dateTime: 'YYYY-MM-DD HH:mm:ss',
    month: 'YYYY-MM',
    time: 'HH:mm:ss',
};
var timeFormatReg = {
    h: /h{1,2}/i,
    m: /m{1,2}/,
    s: /s{1,2}/,
};
var DatePicker = /** @class */ (function (_super) {
    __extends(DatePicker, _super);
    function DatePicker(props) {
        var _this = _super.call(this, props) || this;
        _this.popup = react_1.default.createRef();
        _this.getPlaceholder = function () {
            var _a = _this.props, placeholder = _a.placeholder, _b = _a.type, type = _b === void 0 ? 'date' : _b;
            var langData = _this.state.langData;
            if (placeholder != null) {
                return placeholder;
            }
            return langData.placeholder[type] || langData.placeholder.date;
        };
        _this.getInputIcon = function () {
            var type = _this.props.type;
            if (type === 'time') {
                return react_1.default.createElement(Clock_1.default, null);
            }
            return react_1.default.createElement(Calendar_1.default, null);
        };
        _this.getFormat = function () {
            // eslint-disable-next-line prefer-const
            var _a = _this.props, format = _a.format, _b = _a.type, type = _b === void 0 ? 'date' : _b;
            if (!format) {
                format = defaultFormat[type] || defaultFormat.date;
            }
            return format;
        };
        _this.handleChange = function (value, needClose) {
            if (needClose === void 0) { needClose = true; }
            var _a, _b;
            var _c = _this.props, onChange = _c.onChange, autoClose = _c.autoClose;
            _this.setState({ value: value });
            if (onChange) {
                var valueStr = value ? value.format(_this.getFormat()) : '';
                onChange(value || null, valueStr);
            }
            if (autoClose && needClose) {
                (_b = (_a = _this.popup) === null || _a === void 0 ? void 0 : _a.current) === null || _b === void 0 ? void 0 : _b.hide();
            }
        };
        _this.handleClear = function () {
            var onClear = _this.props.onClear;
            if (onClear) {
                onClear();
            }
            _this.handleChange();
        };
        _this.handleOk = function () {
            var _a, _b;
            var onOk = _this.props.onOk;
            if (onOk) {
                onOk();
            }
            (_b = (_a = _this.popup) === null || _a === void 0 ? void 0 : _a.current) === null || _b === void 0 ? void 0 : _b.hide();
        };
        _this.renderPanel = function () {
            var _a = _this.state, value = _a.value, langData = _a.langData;
            var props = object_omit_1.default(_this.props, [
                'placeholder',
                'lang',
                'value',
                'onOk',
                'size',
                'disabled',
                'clearable',
                'getPopupContainer',
            ]);
            var format = _this.getFormat() || '';
            var showHours = timeFormatReg.h.test(format);
            var showMinutes = timeFormatReg.m.test(format);
            var showSeconds = timeFormatReg.s.test(format);
            return (react_1.default.createElement(date_1.default, __assign({}, props, { showHours: showHours, showMinutes: showMinutes, showSeconds: showSeconds, onOk: _this.handleOk, value: value || dayjs_1.default(), langData: langData, onChange: _this.handleChange })));
        };
        _this.renderTrigger = function () {
            var _a = _this.props, size = _a.size, disabled = _a.disabled, clearable = _a.clearable;
            var value = _this.state.value;
            var format = _this.getFormat();
            var inputValue = value ? value.format(format) : '';
            return (react_1.default.createElement(Input_1.default, { size: size, disabled: disabled, className: helper_1.getClassName('date-picker-input'), placeholder: _this.getPlaceholder(), value: inputValue, clearable: clearable, readOnly: true, onClear: _this.handleClear, suffix: _this.getInputIcon() }));
        };
        var _a = props.type, type = _a === void 0 ? 'date' : _a, _b = props.lang, lang = _b === void 0 ? 'zh' : _b, defaultValue = props.defaultValue;
        var currentType = 'date';
        if (['time', 'month'].includes(type)) {
            currentType = type;
        }
        var langData = I18n_1.default[lang] || I18n_1.default.zh;
        var partialState = {
            currentType: currentType,
            langData: langData,
        };
        if (defaultValue != null) {
            partialState.value = dayjs_1.default(defaultValue);
        }
        _this.state = __assign(__assign({}, _this.state), partialState);
        return _this;
    }
    DatePicker.getDerivedStateFromProps = function (props, state) {
        if ('value' in props) {
            var value = props.value;
            if (props.type === 'time' && typeof value === 'string' && value !== '') {
                value = dayjs_1.default(value).isValid() ? value : dayjs_1.default().format(defaultFormat.date) + " " + value;
            }
            var next = dayjs_1.default(value);
            return { value: value && next.isValid() ? next : undefined };
        }
        return { value: state.value };
    };
    DatePicker.prototype.render = function () {
        var _a = this.props, _b = _a.trigger, trigger = _b === void 0 ? 'click' : _b, getPopupContainer = _a.getPopupContainer;
        return (react_1.default.createElement(popup_1.default, { ref: this.popup, content: this.renderPanel(), trigger: trigger, getContainer: getPopupContainer, openDelay: 0, placement: "bottomLeft", motionClassName: helper_1.getClassName('date-picker-panel') }, this.renderTrigger()));
    };
    DatePicker.defaultProps = {
        trigger: 'click',
        type: 'date',
        lang: 'zh',
        autoClose: true,
        clearable: true,
    };
    return DatePicker;
}(react_1.default.Component));
exports.default = DatePicker;
//# sourceMappingURL=datePicker.js.map