"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var dayjs_1 = __importDefault(require("dayjs"));
var panelLength = {
    date: 7 * 6,
    month: 12,
    year: 12,
};
function getNode(date, options) {
    var checked = options.checked, format = options.format, isCurrent = options.isCurrent, out = options.out, disableDate = options.disableDate;
    var disabled = false;
    if (typeof disableDate === 'function') {
        disabled = disableDate(date);
    }
    return {
        value: date.valueOf(),
        text: date.format(format),
        disabled: disabled,
        checked: checked,
        isCurrent: isCurrent,
        out: out,
    };
}
// 日期列表计算
function getDateList(current, disableDate) {
    var toDay = dayjs_1.default();
    var list = [];
    var currentMonthDays = current.daysInMonth();
    var currentMonthFirstDate = current.startOf('M');
    var currentMonthLastDate = current.endOf('M');
    var currentMonthFirstWeekDay = currentMonthFirstDate.day();
    var prevMonthDays = currentMonthFirstWeekDay ? currentMonthFirstWeekDay - 1 : 6;
    while (prevMonthDays > 0) {
        var d = currentMonthFirstDate.subtract(prevMonthDays, 'd');
        list.push(getNode(d, { out: true, format: 'DD', disableDate: disableDate }));
        prevMonthDays--;
    }
    for (var i = 0; i < currentMonthDays; i++) {
        var d = currentMonthFirstDate.add(i, 'd');
        list.push(getNode(d, {
            checked: d.isSame(current, 'd'),
            isCurrent: d.isSame(toDay, 'd'),
            format: 'DD',
            disableDate: disableDate,
        }));
    }
    var needAppendDays = panelLength.date - list.length;
    for (var j = 1; j <= needAppendDays; j++) {
        var d = currentMonthLastDate.add(j, 'd');
        list.push(getNode(d, { out: true, format: 'DD', disableDate: disableDate }));
    }
    return list;
}
exports.getDateList = getDateList;
// 月份列表计算
function getMonthList(current, langData) {
    var currentMonth = current.month();
    var list = [];
    for (var i = 0; i < panelLength.month; i++) {
        var node = {
            value: i,
            text: langData.text.month[i],
            checked: currentMonth === i,
        };
        list.push(node);
    }
    return list;
}
exports.getMonthList = getMonthList;
// 年份列表计算
function getYearList(current) {
    var getYearNode = function (year, checked, out) {
        return {
            value: year,
            text: "" + year,
            checked: checked,
            out: out,
        };
    };
    var currentYear = current.year();
    var startYear = Math.floor(currentYear / 10) * 10;
    var list = [];
    for (var i = 0; i < panelLength.year; i++) {
        var diff = i - 1;
        var value = startYear + diff;
        var node = getYearNode(value, currentYear === value, diff < 0 || diff > 9);
        list.push(node);
    }
    return list;
}
exports.getYearList = getYearList;
function getYearRange(current) {
    var currentYear = current.year();
    var startYear = Math.floor(currentYear / 10) * 10;
    return [startYear, startYear + 9];
}
exports.getYearRange = getYearRange;
var defaultStep = {
    h: 1,
    m: 1,
    s: 1,
};
// 时间列表计算
function getTimeNodeText(num) {
    if (num < 10) {
        return "0" + num;
    }
    return "" + num;
}
function limitStep(step, max) {
    if (max === void 0) { max = 59; }
    if (!step) {
        return 1;
    }
    return Math.max(Math.min(max, step), 1);
}
function getTimeList(current, step, disableTime) {
    if (step === void 0) { step = defaultStep; }
    var currentH = current.hour();
    var currentM = current.minute();
    var currentS = current.second();
    var getList = function (c, s, length, disable) {
        var list = [];
        var disableNumbers = Array.isArray(disable) ? disable : null;
        for (var i = 0; i < length; i += s) {
            var node = {
                value: i,
                text: getTimeNodeText(i),
                checked: c === i,
            };
            if (disableNumbers) {
                node.disabled = disableNumbers.includes(i);
            }
            list.push(node);
        }
        return list;
    };
    return {
        h: getList(currentH, limitStep(step.h, 23), 24, disableTime && disableTime.h),
        m: getList(currentM, limitStep(step.m), 60, disableTime && disableTime.m),
        s: getList(currentS, limitStep(step.s), 60, disableTime && disableTime.s),
    };
}
exports.getTimeList = getTimeList;
var TIME_ITEM_HEIGHT = 24;
function getTimeColumnScrollTop(index) {
    if (index < 1) {
        return 0;
    }
    return index * TIME_ITEM_HEIGHT;
}
exports.getTimeColumnScrollTop = getTimeColumnScrollTop;
//# sourceMappingURL=calculate.js.map