/// <reference types="lodash" />
import React from 'react';
import { ConfigConsumerProps } from '../config-context';
import { DropdownHOCProps, DropdownHOCState, FocusBy, Option } from './interfaces';
/**
 *
 * @example ./doc/dropdown.md
 * @visibleName Dropdown(下拉框)
 */
export default function DropdownHOC<P extends DropdownHOCProps>(Dropdown: React.ComponentClass<P>): {
    new (props: Readonly<DropdownHOCProps & P>): {
        state: {
            selected: never[];
            visible: boolean;
            focusIndex: number;
            filteredOptions: null;
            menuPosition: string;
        };
        isControlled: boolean;
        disableMouseFocus: boolean;
        focusBy: FocusBy;
        hocRef: any;
        componentDidUpdate(): void;
        adjustPopoverPosition: (trigger: React.RefObject<any>, menu: React.RefObject<any>) => (() => void) & import("lodash").Cancelable;
        handleVisibleChange: (visible: boolean) => void;
        isVisible: () => (DropdownHOCProps & P)["visible"];
        getTransitionName: () => (DropdownHOCProps & P)["transitionName"];
        selectedIndex: (option: Option) => number;
        handleSelect: (option: Option, e: React.MouseEvent<Element, MouseEvent> | React.KeyboardEvent<Element>) => void;
        getSelected: () => never[];
        defaultSearch: (val: string, options: Option[]) => Option[];
        handleSearch: (val: string) => void;
        handleClear: () => void;
        handleKeyDown: (e: React.KeyboardEvent<Element>) => void;
        onDownArrow: () => void;
        onUpArrow: () => void;
        onReturn: (e: React.KeyboardEvent<Element>) => void;
        setFocusIndex: (index: number) => void;
        setFocusBy: (by: string) => void;
        setDisableMouseFocus: (flag: boolean) => void;
        open: () => void;
        close: () => void;
        renderEmpty: () => (DropdownHOCProps & P)["empty"];
        renderDropDown: ({ getPopupContainer: getContextPopupContainer, getPrefixCls, }: ConfigConsumerProps) => JSX.Element;
        render(): JSX.Element;
        context: any;
        setState<K extends "visible" | "filteredOptions" | "selected" | "focusIndex" | "menuPosition">(state: DropdownHOCState | ((prevState: Readonly<DropdownHOCState>, props: Readonly<DropdownHOCProps & P>) => DropdownHOCState | Pick<DropdownHOCState, K> | null) | Pick<DropdownHOCState, K> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<DropdownHOCProps & P> & Readonly<{
            children?: React.ReactNode;
        }>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        componentDidMount?(): void;
        shouldComponentUpdate?(nextProps: Readonly<DropdownHOCProps & P>, nextState: Readonly<DropdownHOCState>, nextContext: any): boolean;
        componentWillUnmount?(): void;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<DropdownHOCProps & P>, prevState: Readonly<DropdownHOCState>): any;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<DropdownHOCProps & P>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<DropdownHOCProps & P>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<DropdownHOCProps & P>, nextState: Readonly<DropdownHOCState>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<DropdownHOCProps & P>, nextState: Readonly<DropdownHOCState>, nextContext: any): void;
    };
    new (props: DropdownHOCProps & P, context?: any): {
        state: {
            selected: never[];
            visible: boolean;
            focusIndex: number;
            filteredOptions: null;
            menuPosition: string;
        };
        isControlled: boolean;
        disableMouseFocus: boolean;
        focusBy: FocusBy;
        hocRef: any;
        componentDidUpdate(): void;
        adjustPopoverPosition: (trigger: React.RefObject<any>, menu: React.RefObject<any>) => (() => void) & import("lodash").Cancelable;
        handleVisibleChange: (visible: boolean) => void;
        isVisible: () => (DropdownHOCProps & P)["visible"];
        getTransitionName: () => (DropdownHOCProps & P)["transitionName"];
        selectedIndex: (option: Option) => number;
        handleSelect: (option: Option, e: React.MouseEvent<Element, MouseEvent> | React.KeyboardEvent<Element>) => void;
        getSelected: () => never[];
        defaultSearch: (val: string, options: Option[]) => Option[];
        handleSearch: (val: string) => void;
        handleClear: () => void;
        handleKeyDown: (e: React.KeyboardEvent<Element>) => void;
        onDownArrow: () => void;
        onUpArrow: () => void;
        onReturn: (e: React.KeyboardEvent<Element>) => void;
        setFocusIndex: (index: number) => void;
        setFocusBy: (by: string) => void;
        setDisableMouseFocus: (flag: boolean) => void;
        open: () => void;
        close: () => void;
        renderEmpty: () => (DropdownHOCProps & P)["empty"];
        renderDropDown: ({ getPopupContainer: getContextPopupContainer, getPrefixCls, }: ConfigConsumerProps) => JSX.Element;
        render(): JSX.Element;
        context: any;
        setState<K extends "visible" | "filteredOptions" | "selected" | "focusIndex" | "menuPosition">(state: DropdownHOCState | ((prevState: Readonly<DropdownHOCState>, props: Readonly<DropdownHOCProps & P>) => DropdownHOCState | Pick<DropdownHOCState, K> | null) | Pick<DropdownHOCState, K> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<DropdownHOCProps & P> & Readonly<{
            children?: React.ReactNode;
        }>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        componentDidMount?(): void;
        shouldComponentUpdate?(nextProps: Readonly<DropdownHOCProps & P>, nextState: Readonly<DropdownHOCState>, nextContext: any): boolean;
        componentWillUnmount?(): void;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<DropdownHOCProps & P>, prevState: Readonly<DropdownHOCState>): any;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<DropdownHOCProps & P>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<DropdownHOCProps & P>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<DropdownHOCProps & P>, nextState: Readonly<DropdownHOCState>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<DropdownHOCProps & P>, nextState: Readonly<DropdownHOCState>, nextContext: any): void;
    };
    defaultProps: {
        multiple: boolean;
        options: never[];
        mouseEnterDelay: number;
        mouseLeaveDelay: number;
        placement: "topLeft" | "topCenter" | "topRight" | "bottomLeft" | "bottomCenter" | "bottomRight";
        empty: null;
        labelKey: string;
        valueKey: string;
        prefixKey: string;
        trigger: string;
    };
    contextType?: React.Context<any> | undefined;
};
